

###################################
# With grain yield
#
###################################
abund<-read.csv("abundance_data.csv",sep=",",h=T,row.names=1) #import OTUs abundance 
rel.abund<-sweep(abund, 1, rowSums(abund), '/')
rel.abund<-sweep(rel.abund,1,100,'*')

traits<-read.csv("line_traits.csv",sep=",",h=T) #import plant traits data
otus<-read.csv("top_signif_OTUs_corre_yield.csv",sep=",",h=T,row.names = 1)


rel.abund<-t(rel.abund)
rel.abund.sigOTUs<-rel.abund[rownames(rel.abund) %in% rownames(otus), ]
rel.abund.sigOTUs<-t(rel.abund.sigOTUs)

#Correlation with yield

#1. You have to make a data frame with your values##

df<-data.frame(rel.abund.sigOTUs,traits$grain.yield)

#2. You can compare 2 of the variables ##

correlation<-cor(df, df$traits.grain.yield)


####You can see the corrrelation visualizing in a scater plot###

otu<-df$Otu152
yield<-df$traits.grain.yield

plot(otu ~ yield)
abline(lm(otu ~ yield, data = df)) 

#####################################
## With all OTUs in rel.abundance and grain.yield (all treatments)
#
###################################

abund<-read.csv("abundance_data.csv",sep=",",h=T,row.names=1) #import OTUs abundance 
rel.abund<-sweep(abund, 1, rowSums(abund), '/')
rel.abund<-sweep(rel.abund,1,100,'*')
traits<-read.csv("line_traits.csv",sep=",",h=T) #import plant traits data

df<-data.frame(rel.abund,traits$grain.yield)

correlation<-cor(df, df$traits.grain.yield, method = "spearman")
write.table(correlation,"grain.yield.corr.OTUs.spearman.csv",sep=",")

#with p-values

library(Hmisc)
df<-as.matrix(df)
correlation.p<-rcorr(df, type = c("spearman"))
pvalues<-correlation.p$P
rvalues<-correlation.p$r
write.table(pvalues,"grain.yield.corr.OTUs.pvalues.spearman.csv",sep = ",")
write.table(rvalues,"grain.yield.corr.OTUs.Rvalues.spearman.csv",sep = ",")

#select OTUs postively correlated with yiel with r>0.10 and pvalue<0.05

r2<-read.table("grain.yield.corr.OTUs.csv",sep = ",",h=T)
pval<-read.table("grain.yield.corr.OTUs.pvalues.csv",sep=",", h=T)

r2.sig<-subset(r2,subset = corr>0.10)
pval.sig<-subset(pval,subset = pvalues<0.05)

final.otus<-r2.sig[rownames(r2.sig) %in% rownames(pval.sig), ]

#####################################
## With all OTUs in rel.abundance and grain.yield DROUGHT
#
###################################

abund<-read.csv("abundance_data.csv",sep=",",h=T,row.names=1) #import OTUs abundance 
rel.abund<-sweep(abund, 1, rowSums(abund), '/')
rel.abund<-sweep(rel.abund,1,100,'*')
traits<-read.csv("line_traits.csv",sep=",",h=T) #import plant traits data

rel.abund<-subset(rel.abund, subset= traits$treatment=="drought")
traits.d<-subset(traits, subset = treatment=="drought")

df<-data.frame(rel.abund,traits.d$grain.yield)

#cor with p-values

library(Hmisc)
df<-as.matrix(df)
correlation<-rcorr(df, type = c("pearson"))
pvalues<-correlation$P
write.table(pvalues,"grain.yield.corr.OTUs.pvalues.DROUGHT.csv",sep = ",")
r2<-correlation$r
write.table(r2,"grain.yield.corr.OTUs.DROUGHT.csv",sep=",")

#####################################
## With all OTUs in rel.abundance and grain.yield CONTROL
#
###################################

abund<-read.csv("abundance_data.csv",sep=",",h=T,row.names=1) #import OTUs abundance 
rel.abund<-sweep(abund, 1, rowSums(abund), '/')
rel.abund<-sweep(rel.abund,1,100,'*')
traits<-read.csv("line_traits.csv",sep=",",h=T) #import plant traits data

rel.abund<-subset(rel.abund, subset= traits$treatment=="control")
traits.c<-subset(traits, subset = treatment=="control")

df<-data.frame(rel.abund,traits.c$grain.yield)

#cor with p-values

library(Hmisc)
df<-as.matrix(df)
correlation<-rcorr(df, type = c("pearson"))
pvalues<-correlation$P
write.table(pvalues,"grain.yield.corr.OTUs.pvalues.CONTROL.csv",sep = ",")
r2<-correlation$r
write.table(r2,"grain.yield.corr.OTUs.CONTROL.csv",sep=",")

#####################################
## With all OTUs in rel.abundance and grain.yield ROBUSTNESS
#
###################################

#We import old data files for performance(robustness:C-D/C*100) 
# made from abundance data (not rel.abundance): 

abund<-read.table("abund.mean.performance.csv",sep = ",",h=T,row.names = 1)

traits<-read.table("line_traits.mean.performance.csv",sep = ",",h=T)

df<-data.frame(abund,traits$grain.yield)

#cor with p-values

library(Hmisc)
df<-as.matrix(df)
correlation<-rcorr(df, type = c("pearson"))
pvalues<-correlation$P
write.table(pvalues,"yield.robustness.corr.OTUs.pvalues.csv",sep = ",")
r2<-correlation$r
write.table(r2,"yield.robustness.corr.OTUs.csv",sep=",")


##################################################
##################################################

#select OTUs postively correlated with yield robustness with r>0.10

r2<-read.table("results/yield.robustness.corr.OTUs.csv",sep = ",",h=T)
r2.sig<-subset(r2,subset = r2>0.10)
write.table(r2.sig,"OTUs_corr_yield.robustness.csv",sep = ",")

#select OTUs postively correlated with yield CONTROL with r>0.10

r2<-read.table("grain.yield.corr.OTUs.CONTROL.csv",sep = ",",h=T)
r2.sig<-subset(r2,subset = r2>0.10)
write.table(r2.sig,"OTUs_corr_yield.CONTROL.csv",sep = ",")

#select OTUs postively correlated with yield DROUGHT with r>0.10

r2<-read.table("grain.yield.corr.OTUs.DROUGHT.csv",sep = ",",h=T)
r2.sig<-subset(r2,subset = r2>0.10)
write.table(r2.sig,"OTUs_corr_yield.DROUGHT.csv",sep = ",")

#Common OTUs correlated with yield CONTROL and DROUGHT

C<-read.table("OTUs_corr_yield.CONTROL.csv",sep = ",",h=T,row.names = 1)
D<-read.table("OTUs_corr_yield.DROUGHT.csv",sep = ",",h=T,row.names = 1)

otus<-subset(C, subset = rownames(C) %in% rownames(D))



##########################################
#Add to sig.OTUs with yield they sequence
##########################################

C<-read.table("results/OTUs_corr_yield.CONTROL.csv",sep = ",",h=T)
D<-read.table("results/OTUs_corr_yield.DROUGHT.csv",sep = ",",h=T)
R<-read.table("results/OTUs_corr_yield.robustness.csv",sep = ",",h=T)
  
tax<-read.table("file.otus.csv",sep = ",",h=T)
seq<-read.table("sequences_OTUs.csv",sep = ",",h=T)

#Control yield correlated

otusC<-tax[tax$OTU %in% C$OTU , ]
otusCseq<-seq[seq$seq_name %in% C$OTU , ]

C_group<-merge(otusC, otusCseq, by.x = "OTU", by.y = "seq_name")
write.table(C_group, "results/OTUs_corr_yield.CONTROL.info.csv",sep = ",")

#Plot some otus:
traits<-read.csv("line_traits.csv",sep=",",h=T) 
abund<-read.csv("abundance_data.csv",sep=",",h=T,row.names=1) 
abund<-sweep(abund, 1, rowSums(abund), '/')
abund<-subset(abund, traits$treatment=="control")
abund<-t(abund)
abund.sigOTUs<-abund[rownames(abund) %in% C$OTU, ]
abund.sigOTUs<-t(abund.sigOTUs)

df<-data.frame(abund.sigOTUs,traits.c$grain.yield)

otu<-df$Otu651
yield<-df$traits.c.grain.yield

plot(otu ~ yield)
abline(lm(otu ~ yield, data = df)) 

#Drought yield correlated

otusD<-tax[tax$OTU %in% D$OTU , ]
otusDseq<-seq[seq$seq_name %in% D$OTU , ]

D_group<-merge(otusD, otusDseq, by.x = "OTU", by.y = "seq_name")
write.table(D_group, "results/OTUs_corr_yield.DROUGHT.info.csv",sep = ",")

#Plot some otus:
traits<-read.csv("line_traits.csv",sep=",",h=T) 
abund<-read.csv("abundance_data.csv",sep=",",h=T,row.names=1) 
abund<-t(abund)
abund.sigOTUs<-abund[rownames(abund) %in% D$OTU, ]
abund.sigOTUs<-t(abund.sigOTUs)

df<-data.frame(abund.sigOTUs,traits$grain.yield)

otu<-df$Otu651
yield<-df$traits.grain.yield

plot(otu ~ yield)
abline(lm(otu ~ yield, data = df)) 

#Robustness correlated

otusR<-tax[tax$OTU %in% R$OTU , ]
otusRseq<-seq[seq$seq_name %in% R$OTU , ]

R_group<-merge(otusR, otusRseq, by.x = "OTU", by.y = "seq_name")
write.table(R_group, "results/OTUs_corr_yield.robustness.info.csv",sep = ",")

#Plot some otus:
traits<-read.csv("line_traits.mean.performance.csv",sep=",",h=T) 
abund<-read.csv("abund.mean.performance.csv",sep=",",h=T,row.names=1) 
abund<-t(abund)
abund.sigOTUs<-abund[rownames(abund) %in% R$OTU, ]
abund.sigOTUs<-t(abund.sigOTUs)

df<-data.frame(abund.sigOTUs,traits$grain.yield)

otu<-df$Otu651
yield<-df$traits.grain.yield

plot(otu ~ yield)
abline(lm(otu ~ yield, data = df)) 


#########################################################
#######################################################

# OTUs positively correlated
# with R2>0.10 and pvalues<0.05. 
# So following we will save this data:

##########################################################

#control yield

r2<-read.table("results/grain.yield.corr.OTUs.CONTROL.csv",sep = ",",h=T)
pval<-read.table("results/grain.yield.corr.OTUs.pvalues.CONTROL.csv",sep=",", h=T)

r2.sig<-subset(r2,subset = r2>0.10)
pval.sig<-subset(pval,subset = pvalues<0.05)

final.otus.C<-r2.sig[rownames(r2.sig) %in% rownames(pval.sig), ]
final.otus.C.b<-tax[tax$OTU %in% final.otus.C$OTU , ]
write.table(final.otus.C.b,"control.csv",sep = ",")

#drought yield

r2<-read.table("results/grain.yield.corr.OTUs.DROUGHT.csv",sep = ",",h=T)
pval<-read.table("results/grain.yield.corr.OTUs.pvalues.DROUGHT.csv",sep=",", h=T)

r2.sig<-subset(r2,subset = r2>0.10)
pval.sig<-subset(pval,subset = pvalues<0.05)

final.otus.D<-r2.sig[rownames(r2.sig) %in% rownames(pval.sig), ]

final.otus.D<-tax[tax$OTU %in% final.otus.D$OTU , ]

write.table(final.otus.D,"drought.csv",sep = ",")

#robustness yield

r2<-read.table("results/yield.robustness.corr.OTUs.csv",sep = ",",h=T)
pval<-read.table("results/yield.robustness.corr.OTUs.pvalues.csv",sep=",", h=T)

r2.sig<-subset(r2,subset = r2>0.10)
pval.sig<-subset(pval,subset = pvalues<0.05)

final.otus.R<-r2.sig[rownames(r2.sig) %in% rownames(pval.sig), ]
final.otus.R<-tax[tax$OTU %in% final.otus.R$OTU , ]

write.table(final.otus.R,"robustness.csv",sep = ",")

####################
#
#Plot some otus
###################

#Control OTUs (final.otus.C) with rel.abund

abund<-read.csv("abundance_data.csv",sep=",",h=T,row.names=1) 
abund<-sweep(abund, 1, rowSums(abund), '/')
abund<-sweep(rel.abund,1,100,'*')

abund<-t(abund)
abund<-subset(abund, traits$treatment=="control")

df<-data.frame(abund, traits.c$grain.yield)

#Plot the main four correlated:

pdf("figures/control.correlated.otus.pdf", h=5,w=5)
par(mfrow=c(3,2), mar=c(4,4,3,2))

otu<-df$Otu507
yield<-df$traits.c.grain.yield
plot(otu ~ yield, xlab= "yield", ylab = "rel.abundance", main="Otu507" )
abline(lm(otu ~ yield, data = df)) 
mtext("R2=0.34", side = 3, cex = 0.6)

otu2<-df$Otu192
yield2<-df$traits.c.grain.yield
plot(otu2 ~ yield2, xlab= "yield", ylab = "rel.abundance", main="Otu192" )
abline(lm(otu2 ~ yield2, data = df)) 
mtext("R2=0.36", side = 3, cex = 0.6)
   
otu3<-df$Otu088
yield3<-df$traits.c.grain.yield
plot(otu3 ~ yield3, xlab= "yield", ylab = "rel.abundance", main="Otu088" )
abline(lm(otu3 ~ yield3, data = df)) 
mtext("R2=0.40", side = 3, cex = 0.6)

otu4<-df$Otu346
yield4<-df$traits.c.grain.yield
plot(otu4 ~ yield4, xlab= "yield", ylab = "rel.abundance", main="Otu346" )
abline(lm(otu4 ~ yield4, data = df)) 
mtext("R2=0.38", side = 3, cex = 0.6)

otu5<-df$Otu646
yield5<-df$traits.c.grain.yield
plot(otu5 ~ yield5, xlab= "yield", ylab = "rel.abundance", main="Otu646" )
abline(lm(otu5 ~ yield5, data = df)) 
mtext("R2=0.34", side = 3, cex = 0.6)
   
   
otu6<-df$Otu713
yield6<-df$traits.c.grain.yield
plot(otu6 ~ yield6, xlab= "yield", ylab = "rel.abundance", main="Otu713" )
abline(lm(otu6 ~ yield6, data = df)) 
mtext("R2=0.33", side = 3, cex = 0.6)

dev.off()

########################################
#transform information OTUs in fasta
####################################

C<-read.table("OTUs_corr_yield.CONTROL.info.csv",sep = ",",h=T)

D<-read.table("OTUs_corr_yield.DROUGHT.info.csv",sep = ",",h=T)

R<-read.table("OTUs_corr_yield.robustness.info.csv",sep = ",",h=T)

###################################################
###################################################
###################################################

# To count the abundance on OTUs that are positively correlated
# with yield under drought, control and robustness. We add this info
# to the tree with these OTUs, together with R and pvalues.

############

#ALL treatments

abund<-read.csv("abundance_data.csv",sep=",",h=T,row.names=1) #import OTUs abundance 
rel.abund<-sweep(abund, 1, rowSums(abund), '/')
rel.abund<-sweep(rel.abund,1,100,'*')
abund.robus<-read.csv("otus_abund_performance_old.data.csv",row.names=1,sep=",",h=T)
rel.abund<-t(rel.abund)
abund.robus<-t(abund.robus)
otus<-read.csv("otus05sig.csv",sep=",",h=T)

rel.abund<-rel.abund[rownames(rel.abund) %in% otus$OTU , ]
abund.robus<-abund.robus[rownames(abund.robus) %in% otus$OTU , ]

x<-as.data.frame(apply(rel.abund, 1, FUN="mean"))
y<-as.data.frame(apply(rel.abund, 1, FUN="sd"))

#robustness
abund.robus<-t(abund.robus)
abund.robus<-abund.robus[rownames(abund.robus) %in% otus$OTU , ]

x<-as.data.frame(apply(abund.robus, 1, FUN="mean"))
y<-as.data.frame(apply(abund.robus, 1, FUN="sd"))

write.table(x, "otus05.abund.mean.robust.csv",sep = ",")

#CONTROL treatment

traits<-read.csv("line_traits.csv",sep=",",h=T) #import plant traits data

abund<-read.csv("abundance_data.csv",sep=",",h=T,row.names=1) #import OTUs abundance 
rel.abund<-sweep(abund, 1, rowSums(abund), '/')
rel.abund<-sweep(rel.abund,1,100,'*')
abund.robus<-read.csv("otus_abund_performance_old.data.csv",row.names=1,sep=",",h=T)

rel.abund<-subset(abund, traits$treatment=="control")

rel.abund<-t(rel.abund)
otus<-read.csv("otus05sig.csv",sep=",",h=T)

rel.abund<-rel.abund[rownames(rel.abund) %in% otus$OTU , ]

x<-as.data.frame(apply(rel.abund, 1, FUN="mean"))
y<-as.data.frame(apply(rel.abund, 1, FUN="sd"))
write.table(x, "otus05.abund.mean.control.csv",sep = ",")

#DROUGHT treatment

traits<-read.csv("line_traits.csv",sep=",",h=T) #import plant traits data

abund<-read.csv("abundance_data.csv",sep=",",h=T,row.names=1) #import OTUs abundance 
rel.abund<-sweep(abund, 1, rowSums(abund), '/')
rel.abund<-sweep(rel.abund,1,100,'*')
abund.robus<-read.csv("otus_abund_performance_old.data.csv",row.names=1,sep=",",h=T)

rel.abund<-subset(abund, traits$treatment=="drought")

rel.abund<-t(rel.abund)
otus<-read.csv("otus05sig.csv",sep=",",h=T)

rel.abund<-rel.abund[rownames(rel.abund) %in% otus$OTU , ]

x<-as.data.frame(apply(rel.abund, 1, FUN="mean"))
y<-as.data.frame(apply(rel.abund, 1, FUN="sd"))
write.table(x, "otus05.abund.mean.drought.csv",sep = ",")


####################################################
# With ocurrence (OTU presence = 1; OTU absence=0)

####################################################

abund<-read.csv("abundance_data.csv",sep=",",h=T,row.names=1) #import OTUs abundance 
abund[abund>0] <-1
otus<-read.csv("otus05sig.csv",sep=",",h=T)

#control
abund<-subset(abund, traits$treatment=="control")
abund<-t(abund)
abund<-abund[rownames(abund) %in% otus$OTU , ]

xc<-as.data.frame(apply(abund, 1, FUN="mean"))
yc<-as.data.frame(apply(abund, 1, FUN="sd"))


#drought
abund<-subset(abund, traits$treatment=="drought")
abund<-t(abund)
abund<-abund[rownames(abund) %in% otus$OTU , ]

xd<-as.data.frame(apply(abund, 1, FUN="mean"))
yd<-as.data.frame(apply(abund, 1, FUN="sd"))

write.table(xc, "control.csv",sep = ",")
write.table(xd, "drought.csv",sep = ",")

###
# Keep otus05 sig. names with taxa info
####

tax<-read.table("file.otus.csv",sep = ",",h=T)

tax.final<-tax[tax$OTU %in% otus$OTU , ]
write.table(tax.final, "otus05_taxa_description.csv",sep = ",")
