#Load packages
library(vegan)
library(BiodiversityR)


diversityresult(rel.abund, index="abundance") #abundance of all data
diversityresult(rel.abund, index="richness") #richness of all data
diversityresult(rel.abund, index = "Shannon")                  #shannon index of all data
diversityresult(rel.abund, index="Jevenness") #evenness

#####Diversitycomp calculate ecological factors from your samples (Shannon, abundance,etc) in groups#####
##Per genotype:

##abundance#
x<-diversitycomp(abund, y=env, factor1="name", method="mean", index="abundance")
write.csv(x,"results/abund.results.csv")

##richness###
x<-diversitycomp(abund, y=env, factor1="name", method="mean", index="richness")
write.csv(x,"results/richness.results.csv")

##shannon###
x<-diversitycomp(abund, y=env, factor1="name", method="mean", index="Shannon")
write.csv(x,"results/shannon.results.csv")

##Jeveness###
x<-diversitycomp(abund, y=env, factor1="name", method="mean", index="Jevenness")
write.csv(x,"results/jeveness.results.csv")

#Per treatment:
#with the mean and sd in the different treatments (control-drought)

diversitycomp(abund, y=env, factor1="treatment",method="mean", index="abundance")
diversitycomp(abund, y=env, factor1="treatment",method="mean", index="richness")
diversitycomp(abund, y=env, factor1="treatment",method="mean", index="Shannon")
diversitycomp(abund, y=env, factor1="treatment",method="mean", index="Jevenness")

diversitycomp(abund, y=env, factor1="treatment",method="sd", index="abundance")
diversitycomp(abund, y=env, factor1="treatment",method="sd", index="richness")
diversitycomp(abund, y=env, factor1="treatment",method="sd", index="Shannon")
diversitycomp(abund, y=env, factor1="treatment",method="sd", index="Jevenness")


#Statistics on the boxplot data: see if the shannon,Jeveness, 
#       richness and abudance differences control vs.drought are significant

names(data)
attach(data)
tapply(values,variable,mean)
tapply(values,treatment,mean)

results = lm(values ~ treatment + variable + treatment*variable, data)
anova(results)
#there is an interaction between treatment (control,drought) and variable 
#   (shannon, richness,etc.) so we run the test separetly

anova(lm(values~treatment,data.abund))
anova(lm(values~treatment,data.rich))
anova(lm(values~treatment,data.shan))
anova(lm(values~treatment,data.jeven))

#results show all parameters are significantly different between treatments

#################################################

#boxplots with abundance of each division 
################################################

tax<-read.table("file.otus.csv",header = T,sep = ",",row.names = 1)
abund<-t(abund)
tax<- tax[rownames(tax) %in% rownames(abund), ]

division <- apply(abund, 2, function(x) tapply(x, tax$division, sum) * 100)
division<-t(division)
rownames(division)<-env$name #change row names in object
write.csv(division,"results/abund.Division.csv")

data<-read.table("results/per taxa/abund.division.organized.csv",header = T,sep = ",")

data.ascom<-subset(data,taxa=="Ascomycota")
data.basid<-subset(data,taxa=="Basidiomycota")
data.chyt<-subset(data,taxa=="Chytridiomycota")
data.glom<-subset(data,taxa=="Glomeromycota")
data.zyg<-subset(data,taxa=="Zygomycota")
data.uncl<-subset(data,taxa=="unclassified")

pdf("figures/boxplot.pdf", w=5, h=5)
par(mfrow=c(3,3),mar=c(4,4,3,2))
x<-boxplot(value ~ treatment, data = data.ascom,
           col = c('white', 'grey'))
mtext("Ascomycota",side=3, line=0.5)

x<-boxplot(value ~ treatment, data = data.basid,
           col = c('white', 'grey'))
mtext("Basidiomycota",side=3, line=0.5)

x<-boxplot(value ~ treatment, data = data.chyt,
           col = c('white', 'grey'))
mtext("Chytridiomycota",side=3, line=0.5)

x<-boxplot(value ~ treatment, data = data.glom,
           col = c('white', 'grey'))
mtext("Glomeromycota",side=3, line=0.5)

x<-boxplot(value ~ treatment, data = data.zyg,
           col = c('white', 'grey'))
mtext("Zygomycota",side=3, line=0.5)

x<-boxplot(value ~ treatment, data = data.uncl,
           col = c('white', 'grey'))
mtext("Unclassified",side=3, line=0.5)

dev.off()

#############################################################
# Calculate shannon, jevennes, richness,abund per taxa group 
# (OTUs separately)
############################################################

abund<-read.csv("abundance_data.csv",sep=",", row.names=1)
env<-read.csv("field location.csv", sep=",", row.names = 1)
tax<-read.table("file.otus.csv",header = T,sep = ",",row.names = 1)

abund<-t(abund)
tax<- tax[rownames(tax) %in% rownames(abund), ]
abund<-t(abund)

##STEP1: to repeat for each taxa level
######################################

taxgroup <- tax$division

rich <- matrix(NA, nrow = nrow(abund), ncol = length(levels(taxgroup)),
            dimnames = list(rownames(abund), levels(taxgroup)))
div <- rich
for(i in levels(taxgroup)){
  x<-abund[, taxgroup == i]
  y <- x
  y[y > 0] <- 1
  if(is.vector(y)){
    r <- y
  } else { r <- rowSums(y)}
  s <- diversity(x)
  rich[, i] <- r
  div[, i] <- s
}

#STEP 2: formulas 
###################

richXtax <- function(taxgroup){
  rich <- matrix(NA, nrow = nrow(abund), ncol = length(levels(taxgroup)),
                 dimnames = list(rownames(abund), levels(taxgroup)))
  for(i in levels(taxgroup)){
    x <- abund[, taxgroup == i]
    x[x > 0] <- 1
    if(is.vector(x)){
      r <- x
    } else { r <- rowSums(x)}
    rich[, i] <- r
  }
  return(rich)
}

divXtax <- function(taxgroup){
  div <- matrix(NA, nrow = nrow(abund), ncol = length(levels(taxgroup)),
                 dimnames = list(rownames(abund), levels(taxgroup)))
  for(i in levels(taxgroup)){
    x <- abund[, taxgroup == i]
    s <- diversity(x)
    div[, i] <- s
  }
  return(div)
}
##############################################



#subdivision
rich <- richXtax(tax$subdivision) # richness
div <- divXtax(tax$subdivision) # diversity


pdf("figures/sudivision.richness.pdf", h=8,w=7)
par(mfrow=c(3,2), mar=c(4,4,3,2))
boxplot(rich[, 1] ~ env$treatment, main="Mucoromycotina", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 2] ~ env$treatment, main="Pezizomycotina", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 3] ~ env$treatment, main="Saccharomycotina", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 4] ~ env$treatment, main="unclassified", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 5] ~ env$treatment, main="Ustilaginomycotina", ylab="OTU richness",col = c('white', 'grey'))
dev.off()

pdf("figures/subdivision.diversity.pdf", h=8,w=7)
par(mfrow=c(3,2), mar=c(4,4,3,2))
boxplot(div[, 1] ~ env$treatment, main="Mucoromycotina", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 2] ~ env$treatment, main="Pezizomycotina", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 3] ~ env$treatment, main="Saccharomycotina", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 4] ~ env$treatment, main="unclassified", ylab="H' diversity")
boxplot(div[, 5] ~ env$treatment, main="Ustilaginomycotina", ylab="H' diversity",col = c('white', 'grey'))
dev.off()


#division
rich <- richXtax(tax$division) # riqueza
div <- divXtax(tax$division) # diversidad
pdf("figures/division.richness.pdf", h=5,w=8, useDingbats=F)
par(mfrow=c(2,3), mar=c(5,5,4,4))
boxplot(rich[, 1] ~ env$treatment, main="Ascomycota", ylab="OTU richness",col = c('white', 'grey'), cex.lab=1.5, cex.main=2, cex.axis=1.5, cex=1.5)
boxplot(rich[, 2] ~ env$treatment, main="Basidiomycota", ylab="OTU richness",col = c('white', 'grey'),cex.lab=1.5, cex.main=2, cex.axis=1.5, cex=1.5)
boxplot(rich[, 3] ~ env$treatment, main="Chytridiomycota", ylab="OTU richness",col = c('white', 'grey'),cex.lab=1.5, cex.main=2, cex.axis=1.5, cex=1.5)
boxplot(rich[, 4] ~ env$treatment, main="Glomeromycota", ylab="OTU richness",col = c('white', 'grey'),cex.lab=1.5, cex.main=2, cex.axis=1.5, cex=1.5)
boxplot(rich[, 5] ~ env$treatment, main="unclassified", ylab="OTU richness",col = c('white', 'grey'),cex.lab=1.5, cex.main=2, cex.axis=1.5, cex=1.5)
boxplot(rich[, 6] ~ env$treatment, main="Zygomycota", ylab="OTU richness",col = c('white', 'grey'),cex.lab=1.5, cex.main=2, cex.axis=1.5, cex=1.5)
dev.off()

pdf("figures/division.diversity.pdf", h=5,w=8, useDingbats=F)
par(mfrow=c(2,3), mar=c(5,5,4,4))
boxplot(div[, 1] ~ env$treatment, main="Ascomycota", ylab="H' diversity",col = c('white', 'grey'), cex.lab=1.5, cex.main=2, cex.axis=1.5, cex=1.5)
boxplot(div[, 2] ~ env$treatment, main="Basidiomycota", ylab="H' diversity",col = c('white', 'grey'), cex.lab=1.5, cex.main=2, cex.axis=1.5, cex=1.5)
boxplot(div[, 3] ~ env$treatment, main="Chytridiomycota", ylab="H' diversity",col = c('white', 'grey'), cex.lab=1.5, cex.main=2, cex.axis=1.5, cex=1.5)
boxplot(div[, 4] ~ env$treatment, main="Glomeromycota", ylab="H' diversity", col = c('white', 'grey'), cex.lab=1.5, cex.main=2, cex.axis=1.5, cex=1.5)
boxplot(div[, 5] ~ env$treatment, main="unclassified", ylab="H' diversity",col = c('white', 'grey'),cex.lab=1.5, cex.main=2, cex.axis=1.5, cex=1.5)
boxplot(div[, 6] ~ env$treatment, main="Zygomycota", ylab="H' diversity",col = c('white', 'grey'),cex.lab=1.5, cex.main=2, cex.axis=1.5, cex=1.5)
dev.off()

      #Calculate the significance control vs drought

t.test(div[, 1] ~ env$treatment) # ***
t.test(div[, 2] ~ env$treatment) # *
t.test(div[, 3] ~ env$treatment) # *
t.test(div[, 4] ~ env$treatment) 
t.test(div[, 5] ~ env$treatment) # **
t.test(div[, 6] ~ env$treatment)

t.test(rich[, 1] ~ env$treatment)
t.test(rich[, 2] ~ env$treatment)
t.test(rich[, 3] ~ env$treatment) # *
t.test(rich[, 4] ~ env$treatment) 
t.test(rich[, 5] ~ env$treatment) # **
t.test(rich[, 6] ~ env$treatment)


#class
rich <- richXtax(tax$class) 
div <- divXtax(tax$class)

pdf("figures/class.richness.pdf", h=8,w=10)
par(mfrow=c(3,4), mar=c(4,4,3,2))
boxplot(rich[, 1] ~ env$treatment, main="Agaricomycetes", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 2] ~ env$treatment, main="Chytridiomycetes", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 3] ~ env$treatment, main="Dothideomycetes", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 4] ~ env$treatment, main="Eurotiomycetes", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 5] ~ env$treatment, main="Exobasidiomycetes", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 6] ~ env$treatment, main="Glomeromycetes", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 7] ~ env$treatment, main="Pezizomycetes", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 8] ~ env$treatment, main="Saccharomycetes", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 9] ~ env$treatment, main="Sordariomycetes", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 10] ~ env$treatment, main="Tremellomycetes", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 11] ~ env$treatment, main="unclassified", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 12] ~ env$treatment, main="Ustilaginomycetes", ylab="OTU richness",col = c('white', 'grey'))
dev.off()

pdf("figures/class.diversity.pdf", h=8,w=10)
par(mfrow=c(3,4), mar=c(4,4,3,2))
boxplot(div[, 1] ~ env$treatment, main="Agaricomycetes", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 2] ~ env$treatment, main="Chytridiomycetes", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 3] ~ env$treatment, main="Dothideomycetes", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 4] ~ env$treatment, main="Eurotiomycetes", ylab="H' diversity")
boxplot(div[, 5] ~ env$treatment, main="Exobasidiomycetes", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 6] ~ env$treatment, main="Glomeromycetes", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 7] ~ env$treatment, main="Pezizomycetes", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 8] ~ env$treatment, main="Saccharomycetes", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 9] ~ env$treatment, main="Sordariomycetes", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 10] ~ env$treatment, main="Tremellomycetes", ylab="H' diversity")
boxplot(div[, 11] ~ env$treatment, main="unclassified", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 12] ~ env$treatment, main="Ustilaginomycetes", ylab="H' diversity",col = c('white', 'grey'))
dev.off()

#order
rich <- richXtax(tax$order) 
div <- divXtax(tax$order) 

pdf("figures/order.richness.pdf", h=10,w=10)
par(mfrow=c(5,4), mar=c(4,4,3,2))
boxplot(rich[, 1] ~ env$treatment, main="Agaricales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 2] ~ env$treatment, main="Auriculariales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 3] ~ env$treatment, main="Cantharellales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 4] ~ env$treatment, main="Capnodiales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 5] ~ env$treatment, main="Chytridiales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 6] ~ env$treatment, main="Cladochytriales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 7] ~ env$treatment, main="Eurotiales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 8] ~ env$treatment, main="Georgefischeriales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 9] ~ env$treatment, main="Glomerales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 10] ~ env$treatment, main="Glomerellales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 11] ~ env$treatment, main="Mortierellales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 12] ~ env$treatment, main="Pezizales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 13] ~ env$treatment, main="Polyporales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 14] ~ env$treatment, main="Saccharomycetales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 15] ~ env$treatment, main="Sebacinales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 16] ~ env$treatment, main="Sordariales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 17] ~ env$treatment, main="Spizellomycetales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 18] ~ env$treatment, main="Tremellales", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 19] ~ env$treatment, main="unclassified", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 20] ~ env$treatment, main="Ustilaginales", ylab="OTU richness",col = c('white', 'grey'))
dev.off()


pdf("figures/order.diversity.pdf", h=10,w=10)
par(mfrow=c(5,4), mar=c(4,4,3,2))
boxplot(div[, 1] ~ env$treatment, main="Agaricales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 2] ~ env$treatment, main="Auriculariales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 3] ~ env$treatment, main="Cantharellales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 4] ~ env$treatment, main="Capnodiales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 5] ~ env$treatment, main="Chytridiales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 6] ~ env$treatment, main="Cladochytriales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 7] ~ env$treatment, main="Eurotiales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 8] ~ env$treatment, main="Georgefischeriales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 9] ~ env$treatment, main="Glomerales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 10] ~ env$treatment, main="Glomerellales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 11] ~ env$treatment, main="Mortierellales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 12] ~ env$treatment, main="Pezizales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 13] ~ env$treatment, main="Polyporales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 14] ~ env$treatment, main="Saccharomycetales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 15] ~ env$treatment, main="Sebacinales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 16] ~ env$treatment, main="Sordariales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 17] ~ env$treatment, main="Spizellomycetales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 18] ~ env$treatment, main="Tremellales", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 19] ~ env$treatment, main="unclassified", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 20] ~ env$treatment, main="Ustilaginales", ylab="H' diversity",col = c('white', 'grey'))
dev.off()


#family
rich <- richXtax(tax$family) 
div <- divXtax(tax$family)
pdf("figures/family.richness.pdf", h=10,w=10)
par(mfrow=c(5,5), mar=c(4,4,3,2))
boxplot(rich[, 1] ~ env$treatment, main="Apiosporaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 2] ~ env$treatment, main="Ascobolaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 3] ~ env$treatment, main="Ceratobasidiaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 4] ~ env$treatment, main="Chaetomiaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 5] ~ env$treatment, main="Cladochytriaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 6] ~ env$treatment, main="Davidiellaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 7] ~ env$treatment, main="Dipodascaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 8] ~ env$treatment, main="Dissoconiaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 9] ~ env$treatment, main="Endochytriaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 10] ~ env$treatment, main="Glomeraceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 11] ~ env$treatment, main="Lachnocladiaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 12] ~ env$treatment, main="Marasmiaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 13] ~ env$treatment, main="Megachytriaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 14] ~ env$treatment, main="Mortierellaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 15] ~ env$treatment, main="Mycosphaerellaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 16] ~ env$treatment, main="Pezizaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 17] ~ env$treatment, main="Plectosphaerellaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 18] ~ env$treatment, main="Sebacinaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 19] ~ env$treatment, main="Tilletiariaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 20] ~ env$treatment, main="Trichocomaceae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 21] ~ env$treatment, main="unclassified", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 22] ~ env$treatment, main="Ustilaginaceae", ylab="OTU richness",col = c('white', 'grey'))
dev.off()

pdf("figures/family.diversity.pdf", h=10,w=10)
par(mfrow=c(5,5), mar=c(4,4,3,2))
boxplot(div[, 1] ~ env$treatment, main="Apiosporaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 2] ~ env$treatment, main="Ascobolaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 3] ~ env$treatment, main="Ceratobasidiaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 4] ~ env$treatment, main="Chaetomiaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 5] ~ env$treatment, main="Cladochytriaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 6] ~ env$treatment, main="Davidiellaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 7] ~ env$treatment, main="Dipodascaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 8] ~ env$treatment, main="Dissoconiaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 9] ~ env$treatment, main="Endochytriaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 10] ~ env$treatment, main="Glomeraceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 11] ~ env$treatment, main="Lachnocladiaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 12] ~ env$treatment, main="Marasmiaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 13] ~ env$treatment, main="Megachytriaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 14] ~ env$treatment, main="Mortierellaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 15] ~ env$treatment, main="Mycosphaerellaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 16] ~ env$treatment, main="Pezizaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 17] ~ env$treatment, main="Plectosphaerellaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 18] ~ env$treatment, main="Sebacinaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 19] ~ env$treatment, main="Tilletiariaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 20] ~ env$treatment, main="Tdivocomaceae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 21] ~ env$treatment, main="unclassified", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 22] ~ env$treatment, main="Ustilaginaceae", ylab="H' diversity",col = c('white', 'grey'))
dev.off()


#genus
rich <- richXtax(tax$genus) 
div <- divXtax(tax$genus)

pdf("figures/genus.richness.pdf", h=9,w=9)
par(mfrow=c(4,4), mar=c(4,4,3,2))
boxplot(rich[, 1] ~ env$treatment, main="Arthrinium", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 2] ~ env$treatment, main="Chaetomium", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 3] ~ env$treatment, main="Cladochytrium", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 4] ~ env$treatment, main="Cladosporium", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 5] ~ env$treatment, main="Dissoconium", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 6] ~ env$treatment, main="Endochytrium", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 7] ~ env$treatment, main="Galactomyces", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 8] ~ env$treatment, main="Nowakowskiella", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 9] ~ env$treatment, main="Ochroconis", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 10] ~ env$treatment, main="Pachyella", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 11] ~ env$treatment, main="Piriformospora", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 12] ~ env$treatment, main="Pseudozyma", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 13] ~ env$treatment, main="Saccobolus", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 14] ~ env$treatment, main="Septofusidium", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 15] ~ env$treatment, main="unclassified", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 16] ~ env$treatment, main="Waitea", ylab="OTU richness",col = c('white', 'grey'))
dev.off()

pdf("figures/genus.diversity.pdf", h=9,w=9)
par(mfrow=c(4,4), mar=c(4,4,3,2))
boxplot(div[, 1] ~ env$treatment, main="Arthrinium", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 2] ~ env$treatment, main="Chaetomium", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 3] ~ env$treatment, main="Cladochytrium", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 4] ~ env$treatment, main="Cladosporium", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 5] ~ env$treatment, main="Dissoconium", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 6] ~ env$treatment, main="Endochytrium", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 7] ~ env$treatment, main="Galactomyces", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 8] ~ env$treatment, main="Nowakowskiella", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 9] ~ env$treatment, main="Ochroconis", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 10] ~ env$treatment, main="Pachyella", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 11] ~ env$treatment, main="Piriformospora", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 12] ~ env$treatment, main="Pseudozyma", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 13] ~ env$treatment, main="Saccobolus", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 14] ~ env$treatment, main="Septofusidium", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 15] ~ env$treatment, main="unclassified", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 16] ~ env$treatment, main="Waitea", ylab="H' diversity",col = c('white', 'grey'))
dev.off()

#specie
rich <- richXtax(tax$specie) 
div <- divXtax(tax$specie) 

pdf("figures/sps.richness.pdf", h=9,w=9)
par(mfrow=c(4,4), mar=c(4,4,3,2))
boxplot(rich[, 1] ~ env$treatment, main="Arthrinium__phaeospermum", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 2] ~ env$treatment, main="Cladochytrium__replicatum", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 3] ~ env$treatment, main="Cladosporium__bruhnei", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 4] ~ env$treatment, main="Dissoconium__dekkeri", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 5] ~ env$treatment, main="Endochytrium__sp.__JEL324", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 6] ~ env$treatment, main="Nowakowskiella__sp.__JEL127", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 7] ~ env$treatment, main="Pachyella__clypeata", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 8] ~ env$treatment, main="Piriformospora__indica", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 9] ~ env$treatment, main="Pseudozyma__flocculosa", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 10] ~ env$treatment, main="Rhizoctonia__zeae", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 11] ~ env$treatment, main="Saccobolus__dilutellus", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 12] ~ env$treatment, main="Septofusidium__herbarum", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 13] ~ env$treatment, main="unclassified", ylab="OTU richness",col = c('white', 'grey'))
boxplot(rich[, 14] ~ env$treatment, main="uncultured__Rozella", ylab="OTU richness",col = c('white', 'grey'))
dev.off()

pdf("figures/sps.diversity.pdf", h=9,w=9)
par(mfrow=c(4,4), mar=c(4,4,3,2))
boxplot(div[, 1] ~ env$treatment, main="Arthrinium__phaeospermum", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 2] ~ env$treatment, main="Cladochytrium__replicatum", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 3] ~ env$treatment, main="Cladosporium__bruhnei", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 4] ~ env$treatment, main="Dissoconium__dekkeri", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 5] ~ env$treatment, main="Endochytrium__sp.__JEL324", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 6] ~ env$treatment, main="Nowakowskiella__sp.__JEL127", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 7] ~ env$treatment, main="Pachyella__clypeata", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 8] ~ env$treatment, main="Piriformospora__indica", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 9] ~ env$treatment, main="Pseudozyma__flocculosa", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 10] ~ env$treatment, main="Rhizoctonia__zeae", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 11] ~ env$treatment, main="Saccobolus__dilutellus", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 12] ~ env$treatment, main="Septofusidium__herbarum", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 13] ~ env$treatment, main="unclassified", ylab="H' diversity",col = c('white', 'grey'))
boxplot(div[, 14] ~ env$treatment, main="uncultured__Rozella", ylab="H' diversity",col = c('white', 'grey'))
dev.off()


###############################################################
###############################################################

#Calculate sequencing depth: rarefaction curve

############################################################

abund<-read.csv("abundance_data.csv",sep=",", row.names=1)

env<-read.csv("field location.csv", sep=",", row.names = 1)
tax<-read.table("file.otus.csv",header = T,sep = ",",row.names = 1)

abund<-t(abund)
tax<- tax[rownames(tax) %in% rownames(rel.abund), ]
abund<-t(abund)


#Now we calculate it as individual-based (based on sequences, not in samples) per treatment

raref.c <- specaccum(abund[env$treatment == "control", ],method = "rarefaction")
raref.d <- specaccum(abund[env$treatment == "drought", ],method = "rarefaction")

pdf("figures/curve.pdf", w = 5, h = 5)
par(lwd=1.5)
plot(raref.c,xvar="individuals",ci=0,axes=FALSE,xlab="Reads",ylab="OTUs")
plot(raref.d,xvar="individuals", add=TRUE,ci=0, lty=2)
axis(1,lwd=1.5)
axis(2,lwd=1.5)
box()
legend("bottomright",c("control","drought"),lty=c(1,2),bty="n")
dev.off()


#for all:

pdf("rarefaction_all.pdf")
rarecurve(abund, step = 100, label = F)
dev.off()


