library("phytools")
library("picante")
library("seqinr")

#Tree with the OTUs correlated with yield (just Ascomycota)
mytree <- read.tree(file="mytree_no_robust.tre")
tip.labels<-mytree$tip.label
tip.labels <- as.matrix(tip.labels)
write.table(tip.labels,file="tree.tip.labels.csv")



#Abundance data with OTUs without rare ones
abund <- read.csv("abundance_data.csv", h=T,sep = ",",row.names = 1) 

#Include the abund data just for OTUs in ascomycota tree
abund <- t(abund)
asco.abund<-abund[rownames(abund) %in% tip.labels , ]



#order OTUs in abund data as in the tree
asco.abund<- asco.abund[mytree$tip.label, ]


#Calculate mean for the OTU abundance and convert in data frame

mean <- rowMeans(asco.abund)
sd <- apply(asco.abund,1,sd)
se <- sd/sqrt(86)

phylosig(mytree,mean,se=se, method="K",test=TRUE,nsim=1000)

###########################
# Just abundance in CONTROL

traits <- read.csv("line_traits.csv", sep = ",",h=T)
rownames(asco.abund)<-traits$sample

traits.c <- subset(traits, treatment=="control")

asco.abund <- t(asco.abund)
asco.abund.c <- asco.abund[rownames(asco.abund) %in% traits.c$sample ,]
                

#Calculate mean for the OTU abundance and convert in data frame
asco.abund.c <- t(asco.abund.c)
mean <- rowMeans(asco.abund.c)
sd <- apply(asco.abund.c,1,sd)
se <- sd/sqrt(43)

phylosig(mytree,mean,se=se, method="K",test=TRUE,nsim=1000)


###########################
# Just abundance in DROUGHT


traits.d <- subset(traits, treatment=="drought")

asco.abund.d <- asco.abund[rownames(asco.abund) %in% traits.d$sample ,]


#Calculate mean for the OTU abundance and convert in data frame
asco.abund.d <- t(asco.abund.d)
mean <- rowMeans(asco.abund.d)
sd <- apply(asco.abund.d,1,sd)
se <- sd/sqrt(43)

phylosig(mytree,mean,se=se, method="K",test=TRUE,nsim=1000)


###################################################################
##################################################################

# now we used the big Ascomycota tree and pruned it with the OTUs 
# correlated to yield (to see if tree distances are conserved 
# from the original tree)

################################################################


#Tree with the OTUs correlated with yield (just Ascomycota)
mytree <- read.tree(file="RAxML_bestTree.Ascomycota")
prunedtree <- prune.sample(asco.abund, mytree)


#order OTUs in abund data as in the tree
asco.abund <- t(asco.abund)
asco.abund<- asco.abund[prunedtree$tip.label, ]

#Calculate mean for the OTU abundance and convert in data frame

mean <- rowMeans(asco.abund)
sd <- apply(asco.abund,1,sd)
se <- sd/sqrt(86)

phylosig(prunedtree,mean,se=se, method="K",test=TRUE,nsim=1000)

###########################
# Just abundance in CONTROL

asco.abund <- t(asco.abund)
asco.abund.c <- asco.abund[rownames(asco.abund) %in% traits.c$sample ,]


#Calculate mean for the OTU abundance and convert in data frame
asco.abund.c <- t(asco.abund.c)
mean <- rowMeans(asco.abund.c)
sd <- apply(asco.abund.c,1,sd)
se <- sd/sqrt(43)

phylosig(prunedtree,mean,se=se, method="K",test=TRUE,nsim=1000)


###########################
# Just abundance in DROUGHT

asco.abund.d <- asco.abund[rownames(asco.abund) %in% traits.d$sample ,]


#Calculate mean for the OTU abundance and convert in data frame
asco.abund.d <- t(asco.abund.d)
mean <- rowMeans(asco.abund.d)
sd <- apply(asco.abund.d,1,sd)
se <- sd/sqrt(43)

phylosig(prunedtree,mean,se=se, method="K",test=TRUE,nsim=1000)

##################################################################

# now we used the big Ascomycota tree and pruned it with the OTUs 
# correlated to yield (to see if tree distances are conserved 
# from the original tree) but with OCURRENCE OTUs (not abund)

#Transform abund in ocurrence matrix
asco.abund[asco.abund>0]=1

#order OTUs in abund data as in the tree
asco.abund <- t(asco.abund)
asco.abund<- asco.abund[prunedtree$tip.label, ]

#Calculate mean for the OTU abundance and convert in data frame

mean <- rowMeans(asco.abund)
sd <- apply(asco.abund,1,sd)
se <- sd/sqrt(86)

phylosig(prunedtree,mean,se=se, method="K",test=TRUE,nsim=1000)

# Just abundance in CONTROL

asco.abund <- t(asco.abund)
asco.abund.c <- asco.abund[rownames(asco.abund) %in% traits.c$sample ,]


#Calculate mean for the OTU abundance and convert in data frame
asco.abund.c <- t(asco.abund.c)
mean <- rowMeans(asco.abund.c)
sd <- apply(asco.abund.c,1,sd)
se <- sd/sqrt(43)

phylosig(prunedtree,mean,se=se, method="K",test=TRUE,nsim=1000)

# Just abundance in DROUGHT

asco.abund.d <- asco.abund[rownames(asco.abund) %in% traits.d$sample ,]


#Calculate mean for the OTU abundance and convert in data frame
asco.abund.d <- t(asco.abund.d)
mean <- rowMeans(asco.abund.d)
sd <- apply(asco.abund.d,1,sd)
se <- sd/sqrt(43)

phylosig(prunedtree,mean,se=se, method="K",test=TRUE,nsim=1000)
